/usr/bin/qmake symfonie.pro
#make clean
make
run-standalone.sh ./symfonie
